import { Driver } from "../driver/Driver";
import { ConnectionOptions } from "./ConnectionOptions";
import { Repository } from "../repository/Repository";
import { EventSubscriberInterface } from "../subscriber/EventSubscriberInterface";
import { EntityMetadata } from "../metadata-builder/metadata/EntityMetadata";
import { ConstructorFunction } from "../common/ConstructorFunction";
import { EntityListenerMetadata } from "../metadata-builder/metadata/EntityListenerMetadata";
import { EntityManager } from "../repository/EntityManager";
/**
 * A single connection instance to the database. Each connection has its own repositories, subscribers and metadatas.
 */
export declare class Connection {
    private repositoryAndMetadatas;
    /**
     * Database connection options.
     */
    readonly options: ConnectionOptions;
    /**
     * Gets EntityManager of this connection.
     */
    readonly entityManager: EntityManager;
    /**
     * The name of the connection.
     */
    readonly name: string;
    /**
     * Database driver used by this connection.
     */
    readonly driver: Driver;
    /**
     * All entity metadatas that are registered for this connection.
     */
    private readonly entityMetadatas;
    /**
     * All entity listener metadatas that are registered for this connection.
     */
    readonly entityListeners: EntityListenerMetadata[];
    /**
     * All subscribers that are registered for this connection.
     */
    readonly subscribers: EventSubscriberInterface<any>[];
    constructor(name: string, driver: Driver, options: ConnectionOptions);
    /**
     * All repositories that are registered for this connection.
     */
    readonly repositories: Repository<any>[];
    /**
     * Performs connection to the database.
     */
    connect(): Promise<void>;
    /**
     * Creates database schema for all entities registered in this connection.
     */
    createSchema(): Promise<void>;
    /**
     * Closes this connection.
     */
    close(): Promise<void>;
    /**
     * Gets repository for the given entity class.
     */
    getRepository<Entity>(entityClass: ConstructorFunction<Entity> | Function): Repository<Entity>;
    /**
     * Registers entity metadatas for the current connection.
     */
    addEntityMetadatas(metadatas: EntityMetadata[]): Connection;
    /**
     * Registers entity listener metadatas for the current connection.
     */
    addEntityListenerMetadatas(metadatas: EntityListenerMetadata[]): Connection;
    /**
     * Registers subscribers for the current connection.
     */
    addSubscribers(subscribers: EventSubscriberInterface<any>[]): Connection;
    private createRepoMeta(metadata);
}
