/*!
 
 */
import { ConnectionOptions } from "./connection/ConnectionOptions";
import { ConnectionManager } from "./connection/ConnectionManager";
import { Connection } from "./connection/Connection";
declare const connectionManager: ConnectionManager;
/**
 * All options to help to create a new connection.
 */
export interface CreateConnectionOptions {
    /**
     * Driver type. Mysql is the only driver supported at this moment.
     */
    driver: "mysql";
    /**
     * Database connection options.
     */
    connection: ConnectionOptions;
    /**
     * Connection name. By default its called "default". Different connections must have different names.
     */
    connectionName?: string;
    /**
     * Entities to be loaded for the new connection.
     */
    entities?: Function[];
    /**
     * Subscribers to be loaded for the new connection.
     */
    subscribers?: Function[];
    /**
     * List of directories from where entities will be loaded.
     */
    entityDirectories?: string[];
    /**
     * List of directories from where subscribers will be loaded.
     */
    subscriberDirectories?: string[];
}
/**
 * Creates a new connection with the database.
 */
export declare function createConnection(options: CreateConnectionOptions): Promise<Connection>;
export default connectionManager;
export { Connection } from "./connection/Connection";
export { ConnectionManager } from "./connection/ConnectionManager";
export { ConnectionOptions } from "./connection/ConnectionOptions";
export { Driver } from "./driver/Driver";
export { MysqlDriver } from "./driver/MysqlDriver";
export { QueryBuilder } from "./query-builder/QueryBuilder";
export { EntityManager } from "./repository/EntityManager";
export { Repository } from "./repository/Repository";
export { FindOptions } from "./repository/FindOptions";
export { InsertEvent } from "./subscriber/event/InsertEvent";
export { UpdateEvent } from "./subscriber/event/UpdateEvent";
export { RemoveEvent } from "./subscriber/event/RemoveEvent";
export { EventSubscriberInterface } from "./subscriber/EventSubscriberInterface";
