/*!
 
 */
"use strict";
var ConnectionManager_1 = require("./connection/ConnectionManager");
var MysqlDriver_1 = require("./driver/MysqlDriver");
var connectionManager = new ConnectionManager_1.ConnectionManager();
/**
 * Creates a new connection with the database.
 */
function createConnection(options) {
    var connection;
    switch (options.driver) {
        case "mysql":
            connection = connectionManager.createConnection(options.connectionName, new MysqlDriver_1.MysqlDriver(), options.connection);
            break;
        default:
            throw new Error("Wrong driver " + options.driver + " given. Supported drivers are: \"mysql\"");
    }
    if (options.entityDirectories && options.entityDirectories.length > 0)
        connectionManager.importEntitiesFromDirectories(options.connectionName, options.entityDirectories);
    if (options.entities)
        connectionManager.importEntities(options.connectionName, options.entities);
    if (options.subscriberDirectories && options.subscriberDirectories.length > 0)
        connectionManager.importSubscribersFromDirectories(options.connectionName, options.subscriberDirectories);
    if (options.subscribers)
        connectionManager.importSubscribers(options.subscribers);
    return connection.connect().then(function () { return connection; });
}
exports.createConnection = createConnection;
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = connectionManager;
// export everything commonly used
var Connection_1 = require("./connection/Connection");
exports.Connection = Connection_1.Connection;
var ConnectionManager_2 = require("./connection/ConnectionManager");
exports.ConnectionManager = ConnectionManager_2.ConnectionManager;
var MysqlDriver_2 = require("./driver/MysqlDriver");
exports.MysqlDriver = MysqlDriver_2.MysqlDriver;
var QueryBuilder_1 = require("./query-builder/QueryBuilder");
exports.QueryBuilder = QueryBuilder_1.QueryBuilder;
var EntityManager_1 = require("./repository/EntityManager");
exports.EntityManager = EntityManager_1.EntityManager;
var Repository_1 = require("./repository/Repository");
exports.Repository = Repository_1.Repository;
//# sourceMappingURL=typeorm.js.map